[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,98 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#include <cuda/experimental/stf.cuh>
/*
* The goal of this test is to ensure that using read access modes actually
* results in concurrent tasks
*/
using namespace cuda::experimental::stf;
/**
* @brief Call `__nanosleep` (potentially repeatedly) to sleep `nanoseconds` nanoseconds. Supports sleep times longer
* than 4 billion nanoseconds (i.e. 4 seconds).
*
* @param nanoseconds how many nanoseconds to sleep
* @return void
*/
__global__ void nano_sleep(unsigned long long nanoseconds)
{
#if defined(__CUDA_ARCH__) && (__CUDA_ARCH__ >= 700)
static constexpr auto m = std::numeric_limits<unsigned int>::max();
for (;;)
{
if (nanoseconds > m)
{
__nanosleep(m);
nanoseconds -= m;
}
else
{
__nanosleep(static_cast<unsigned int>(nanoseconds));
break;
}
}
#else
const clock_t end = clock() + nanoseconds / (1000000000ULL / CLOCKS_PER_SEC);
while (clock() < end)
{
// busy wait
}
#endif
}
void run(context& ctx, int NTASKS, int ms)
{
int dummy[1];
auto handle = ctx.logical_data(dummy);
ctx.task().add_deps(handle.rw())->*[](cudaStream_t stream) {
nano_sleep<<<1, 1, 0, stream>>>(0);
};
for (int iter = 0; iter < 10; iter++)
{
for (int k = 0; k < NTASKS; k++)
{
ctx.task().add_deps(handle.read())->*[&](cudaStream_t stream) {
nano_sleep<<<1, 1, 0, stream>>>(ms * 1000ULL * 1000ULL);
};
}
ctx.task().add_deps(handle.rw())->*[&](cudaStream_t stream) {
nano_sleep<<<1, 1, 0, stream>>>(0);
};
}
ctx.finalize();
}
int main(int argc, char** argv)
{
int NTASKS = 256;
int ms = 40;
if (argc > 1)
{
NTASKS = atoi(argv[1]);
}
if (argc > 2)
{
ms = atoi(argv[2]);
}
context ctx;
run(ctx, NTASKS, ms);
ctx = graph_ctx();
run(ctx, NTASKS, ms);
}